AnalysisProfile class

Constructors

AnalysisProfile(Type type, {List<MediaRequest> mediaList = const [], Map<String, dynamic> params = const {}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
mediaList List<MediaRequest>
final
params Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Type
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited