CaptureRequest class
Constructors
-
CaptureRequest({List<
AnalysisProfile> analysisProfileList = const [], Map<String, dynamic> folderMeta = const {}, List<MediaRequest> additionalMediaList = const [], CameraPosition cameraPosition = CameraPosition.front}) -
const
Properties
-
additionalMediaList
→ List<
MediaRequest> -
final
-
analysisProfileList
→ List<
AnalysisProfile> -
final
- cameraPosition → CameraPosition
-
final
-
folderMeta
→ Map<
String, dynamic> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited