CenterHintCustomization class

Constructors

CenterHintCustomization({String? textFont, String? textFontStyle, String? textColor, int? textSize, int? verticalPosition, int? textAlpha, bool? centerBackground, String? centerHintBackgroundColor, int? centerHintBackgroundAlpha, int? centerHintCornerRadius})

Properties

centerBackground bool?
final
centerHintBackgroundAlpha int?
final
centerHintBackgroundColor String?
final
centerHintCornerRadius int?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textAlpha int?
final
textColor String?
final
textFont String?
final
textFontStyle String?
final
textSize int?
final
verticalPosition int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic json) CenterHintCustomization