FaceFrameCustomization class

Constructors

FaceFrameCustomization({GeometryType? geometryType, int? geometryTypeRadius, int? strokeWidth, String? strokeFaceNotAlignedColor, String? strokeFaceAlignedColor, int? strokeAlpha, int? strokePadding})

Properties

geometryType GeometryType?
final
geometryTypeRadius int?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeAlpha int?
final
strokeFaceAlignedColor String?
final
strokeFaceNotAlignedColor String?
final
strokePadding int?
final
strokeWidth int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic json) FaceFrameCustomization