AntiScamCustomization class
Constructors
Properties
- backgroundColor → String?
-
final
- backgroundOpacity → int?
-
final
- cornerRadius → int?
-
final
- enable → bool?
-
final
- flashColor → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textAlpha → int?
-
final
- textColor → String?
-
final
- textFont → String?
-
final
- textMessage → String?
-
final
- textSize → int?
-
final
- textStyle → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
dynamic json) → AntiScamCustomization