CenterHintCustomization class
Constructors
Properties
- centerBackground → bool?
-
final
- centerHintBackgroundAlpha → int?
-
final
- centerHintBackgroundColor → String?
-
final
- centerHintCornerRadius → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textAlpha → int?
-
final
- textColor → String?
-
final
- textFont → String?
-
final
- textFontStyle → String?
-
final
- textSize → int?
-
final
- verticalPosition → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
dynamic json) → CenterHintCustomization