ToolbarCustomization class
Constructors
Properties
- backgroundAlpha → int?
-
final
- backgroundColor → String?
-
final
- closeButtonColor → String?
-
final
- closeButtonIcon → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTitleCentered → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleAlpha → int?
-
final
- titleColor → String?
-
final
- titleFont → String?
-
final
- titleFontStyle → String?
-
final
- titleSize → int?
-
final
- titleText → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map json) → ToolbarCustomization