Analysis class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mediaList
→ List<
Media> -
final
- mode → Mode
-
final
-
params
→ Map<
String, String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeReductionStrategy → SizeReductionStrategy
-
final
- type → Type
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited